/* 
Analyze Model Generated Data
Allan Collard-Wexler
July 9 2008
*/

shell date

clear
set mem 1g
set more off
cap log close

program define processcounteranalyze
quietly {
compress
iis plantid
tis year

gen newdemand=mod(demand,10)

rename demand oldemand
rename newdemand demand

sort markettype demand
merge m:1 markettype demand using "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/CONCRETE/structure/demand10meanbins191"

gen lcountempconstruction=ln(countempconstruction) 

egen newmarket=group(markettype market)
rename market oldmarket
rename newmarket market


drop if markettype==0
//drop if year<(50-23)
//drop if year>25
 }
end


program define counteranalyze
quietly {

gen size=(me>0)+(me>3)+(me>5)

/* Transition Matrix */


sort market year
by market year: gen compw=(_n==1)


gen firmnumber=comp1+(size>0)


replace firmnumber=. if compw~=1
by market: egen meanfirm=mean(firmnumber)

replace lcountempconstruction=. if compw~=1
by market: egen meanlcountempconstruction=mean(lcountempconstruction)

gen dm_lcountempconstruction=lcountempconstruction-meanlcountempconstruction
gen dm_firmnumber=firmnumber-meanfirm




gen compm1=firmnumber*(markettype==1)
replace compm1=. if markettype~=1 | compw~=1
gen compm2=firmnumber*(markettype==2)
replace compm2=. if markettype~=2 | compw~=1
gen compm3=firmnumber*(markettype==3)
replace compm3=. if markettype~=3 | compw~=1
gen compm4=firmnumber*(markettype==4)
replace compm4=. if markettype~=4 | compw~=1


gen zero=firmnumber==0 
replace zero=. if compw~=1
gen monopoly=firmnumber==1
replace monopoly=. if compw~=1
gen duopoly=firmnumber==2
replace duopoly=. if compw~=1
gen competition=firmnumber>2
replace competition=. if compw~=1


gen small=size==1
replace small=. if size==0
gen medium=size==2
replace medium=. if size==0
gen big=size==3
replace big=. if size==0

gen rampup=(action>size)
replace rampup=. if size==0
replace rampup=. if action==0

gen rampdown=(action<size)
replace rampdown=. if size==0
replace rampdown=. if action==0

gen entry=(size==0)*(action>0)
gen exit=(size>0)*(action==0)

egen total_entry=total(entry)
egen total_exit=total(exit)
gen isfirm=(size>0) 
egen total_firms=total(isfirm)

gen entry_rate=total_entry/total_firms
gen exit_rate=total_exit/total_firms

replace exit=. if (size==0)
replace entry=. if (action==0) & (size==0)

sort markettype market plantid year
by markettype market plantid: gen plantyear=_n
by markettype market plantid: egen possible_plantyears=max(plantyear)

cap gen firstcomp1=comp1>0
cap gen secondcomp1=comp1>1
cap gen logcomp1=ln(comp1)*(comp1>2)
cap replace logcomp1=0 if logcomp1==.

cap gen lcomp=ln(comp1+1) 

mlogit actiondata i.size lcountempconstruction firstcomp secondcomp logcomp, base(0) iter(60)
estimates store e1
mlogit actiondata i.size lcountempconstruction firstcomp secondcomp logcomp i.markettype, base(0) iter(60)
estimates store e2

}

disp "_________________________________________________________________"

disp "Market Level Variables"
tab markettype
tabstat firmnumber dm_firmnumber compm1 compm2 compm3 compm4 zero monopoly duopoly competition lcountempconstruction dm_lcountempconstruction, stat(mean sd) col(stat)
corr firmnumber lcountempconstruction
corr size lcountempconstruction
corr firmnumber year
disp 
xtreg firmnumber lcountempconstruction,fe i(market)

disp "Plant Level Variables"
tabstat big medium small entry exit rampup rampdown possible_plantyears, stat(mean semean) col(stat)
tab size action 

disp "Evolution of the Market"
tabstat firmnumber entry exit rampup rampdown , by(year)

disp "Multinomial Logit"
estimates table e1 e2,b(%5.3g) se(%5.3g)  stats(N ll)
disp "_________________________________________________________________"

end


/*------------------------------------------------------------------------------------*/
/*           ORIGINAL (REAL) DATA                                                               */
/*                                                                                    */
/*                                                                                    */
/*                                                                                    */
/*------------------------------------------------------------------------------------*/

use first_stage_4_bootdata

tab competition
rename action actiondata
rename competition comp1
drop small medium large 

gen me=firmstate
gen mestate=firmstate

gen market=countyindex
gen markettype=newaverageplant 
rename lcountyempconstruction lcountempconstruction

egen plantid=group(firm countyindex)

counteranalyze


// Disclosure Analysis
log using Disclose_AnalyzeSimData2.log, replace
tab markettype

tab zero
tab monopoly
tab duopoly
tab competition

tab big 
tab medium
tab small
tab exit
tab entry 
tab rampup
tab rampdown 


//tab action me 
tab actiondata size 
tab actiondata firstcomp
tab actiondata secondcomp
tab actiondata markettype
log close



/*-----------------------------------
CCP 
------------------------------------*/
clear
/*-----------------------------------------------------------------------*/
//            CCP DATA 
/*-----------------------------------------------------------------------*/
infile plantid market year actiondata statedata mestate demand comp1 markettype using sim_ccp5.asc
processcounteranalyze
keep if year>25
counteranalyze
clear


/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*            NO MARKET EFFECT MODEL                                                  */
/*                                                                                    */
/*                                                                                    */
/*                                                                                    */
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------------*/



clear
/*-----------------------------------------------------------------------*/
//            BASELINE DATA 
/*-----------------------------------------------------------------------*/
infile plantid market year actiondata statedata mestate demand comp1 markettype using simGMM_baseline5.asc
processcounteranalyze
keep if year>25
counteranalyze
clear
/*-----------------------------------------------------------------------*/
//            NO DEMAND CHANGE     
/*-----------------------------------------------------------------------*/
infile plantid market year actiondata statedata mestate demand comp1 markettype using simGMM_nofluct5.asc
processcounteranalyze
keep if year>25
counteranalyze
clear
/*-----------------------------------------------------------------------*/
//            5 YEARS OF SMOOTHING                                       */
/*-----------------------------------------------------------------------*/
infile plantid market year actiondata statedata mestate demand comp1 markettype using simGMM_5years5.asc
processcounteranalyze
keep if year>25
counteranalyze
/*-----------------------------------------------------------------------*/
//            SAME DATA MISTAKE
/*-----------------------------------------------------------------------*/
clear
infile plantid market year actiondata statedata mestate demand comp1 markettype using simGMM_mistake5.asc
processcounteranalyze
keep if year>25
counteranalyze




log close