/* 
Allan Collard-Wexler
November 11 2009
Bootstrap of First Stage of the Model

*/

clear
set more off
set mem 2g
set matsize 10000
local x=400
local groupvar="newaverage"
// Load Estout
quietly do "/rdcprojects/ny1/ny00707/programs/estout/estout.ado"
// Load Sutex
quietly do "/rdcprojects/ny1/ny00707/programs/sutex/sutex.ado"


// A Program to Export Estimates 
cap program drop export_coeffs
program export_coeffs
args filenameexport thematrix
matrix exportermatrix=`thematrix'
svmat exportermatrix
outfile exportermatrix* using `filenameexport' in 1, replace
drop exportermatrix*
end

// Programs to Process the data for model fit 
program define processcounteranalyze
quietly {
compress
iis plantid
tis year

gen newdemand=mod(demand,10)

rename demand oldemand
rename newdemand demand

sort markettype demand
merge m:1 markettype demand using demand10meanbins400

gen lcountempconstruction=ln(countyempconstruction) 

egen newmarket=group(markettype market)
rename market oldmarket
rename newmarket market


drop if markettype==0
drop if year<(50-23)
 }
end


program define counteranalyze
quietly {

gen size=(me>0)+(me>3)+(me>5)

/* Transition Matrix */


sort market year
by market year: gen compw=(_n==1)


gen firmnumber=comp1+(size>0)


replace firmnumber=. if compw~=1
by market: egen meanfirm=mean(firmnumber)

replace lcountempconstruction=. if compw~=1
by market: egen meanlcountempconstruction=mean(lcountempconstruction)

gen dm_lcountempconstruction=lcountempconstruction-meanlcountempconstruction
gen dm_firmnumber=firmnumber-meanfirm




gen compm1=firmnumber*(markettype==1)
replace compm1=. if markettype~=1 | compw~=1
gen compm2=firmnumber*(markettype==2)
replace compm2=. if markettype~=2 | compw~=1
gen compm3=firmnumber*(markettype==3)
replace compm3=. if markettype~=3 | compw~=1
gen compm4=firmnumber*(markettype==4)
replace compm4=. if markettype~=4 | compw~=1


gen zero=firmnumber==0 
replace zero=. if compw~=1
gen monopoly=firmnumber==1
replace monopoly=. if compw~=1
gen duopoly=firmnumber==2
replace duopoly=. if compw~=1
gen competition=firmnumber>2
replace competition=. if compw~=1


gen small=size==1
replace small=. if size==0
gen medium=size==2
replace medium=. if size==0
gen big=size==3
replace big=. if size==0

gen rampup=(action>size)
replace rampup=. if size==0
replace rampup=. if action==0

gen rampdown=(action<size)
replace rampdown=. if size==0
replace rampdown=. if action==0

gen entry=(size==0)*(action>0)
gen exit=(size>0)*(action==0)

egen total_entry=total(entry)
egen total_exit=total(exit)
gen isfirm=(size>0) 
egen total_firms=total(isfirm)

gen entry_rate=total_entry/total_firms
gen exit_rate=total_exit/total_firms

replace exit=. if (size==0)
replace entry=. if (action==0) & (size==0)

sort markettype market plantid year
by markettype market plantid: gen plantyear=_n
by markettype market plantid: egen possible_plantyears=max(plantyear)

cap gen firstcomp1=comp1>0
cap gen secondcomp1=comp1>1
cap gen logcomp1=ln(comp1)*(comp1>2)
cap replace logcomp1=0 if logcomp1==.

cap gen lcomp=ln(comp1+1) 

mlogit actiondata i.size lcountempconstruction firstcomp secondcomp logcomp, base(0) iter(60)
estimates store e1
mlogit actiondata i.size lcountempconstruction firstcomp secondcomp logcomp i.markettype, base(0) iter(60)
estimates store e2

}

disp "_________________________________________________________________"

disp "Market Level Variables"
tab markettype
tabstat firmnumber  compm1 compm2 compm3 compm4 zero monopoly duopoly competition lcountempconstruction dm_lcountempconstruction entry_rate exit_rate, stat(mean) col(stat) save
matrix bm=r(StatTotal)

tabstat dm_firmnumber, stat(sd) col(stat) save
matrix bm2=r(StatTotal)


corr firmnumber lcountempconstruction
matrix flcounty=r(rho)
matrix colnames flcounty =corr_nfirm_lempc
corr size lcountempconstruction
matrix slcounty=r(rho)
matrix colnames slcounty =corr_size_lempc
corr firmnumber year
matrix fy=r(rho)
matrix colnames fy=corr_nfirm_year

disp "Plant Level Variables"
tabstat big medium small entry exit rampup rampdown possible_plantyears, stat(mean) col(stat) save
matrix bp=r(StatTotal)

//tab size action 
//disp "Multinomial Logit"
//estimates table e1 e2,b(%5.3g) se(%5.3g)  stats(N ll)
disp "_________________________________________________________________"

end


cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/ECMA_4/"


local spec1="lcountyempconstruction i.firmstate firstcomp secondcomp thirdcomp logcomp"

use first_stage_4_bootdata, replace

******************************************************************************************
// MAIN BOOTSTRAP LOOP
******************************************************************************************

cap program drop boot_data
program boot_data, eclass
	use first_stage_4_bootdata, clear
	drop if thedemand==.
	bsample , cluster(countyindex)

	drop small medium large 
	rename action actiondata
	rename competition comp1

	gen me=firmstate
	gen mestate=firmstate

	gen market=countyindex
	gen markettype=newaverageplant 
	rename lcountyempconstruction lcountempconstruction

	egen plantid=group(firm countyindex)
	
	counteranalyze
	tempname bb
	matrix `bb'=bm,bm2,flcounty,slcounty,fy,bp
	matrix list `bb'

	ereturn post `bb'
	ereturn local cmd="bootstrap"	
end

******************************************************************************************
// MAIN BOOTSTRAP LOOP
******************************************************************************************


cap program drop sim_pmu_model
program sim_pmu_model, eclass
	use first_stage_4_bootdata, clear
	drop if thedemand==.
	bsample , cluster(countyindex)
	// 1) Run Mlogit
	local spec1="lcountyempconstruction i.firmstate firstcomp secondcomp thirdcomp logcomp"
	mlogit action `spec1' i.newaverage, vsquish noemptycells
	estimates store modelD 
	// Send it to GAUSS
	export_coeffs modelEbeta e(b)
	
	// 2) GAUSS BIT
	shell tgauss -b BSim_Maker.e

clear
infile plantid market year actiondata statedata mestate demand comp1 markettype using boot_ccp.asc
// list plantid market year actiondata mestate comp1 if market==20 & markettype==2
//  gen entry=(actiondata>0)&(mestate==0)
// gen exit=(actiondata==0)&(mestate>0)
// gen isfirm=(mestate>0)
// 
// tabstat entry exit isfirm if market==20 & markettype==4, by(year) stat(sum)
// 
// tabstat entry exit isfirm if year<49, by(year) stat(sum)
processcounteranalyze
counteranalyze

tempname bb

matrix `bb'=bm,bm2,flcounty,slcounty,fy,bp
matrix list `bb'

ereturn post `bb'
ereturn local cmd="bootstrap"

end


******************************************************************************************
// MAIN BOOTSTRAP LOOP
******************************************************************************************

cap program drop sim_model
program sim_model, eclass
	// 1) Pull Estimate from Bootstraps	
	clear
	use boot_df in $bootpull

	global bootpull=$bootpull+1
	keep _b_fixed_cost1ii-_b_trans_3_to_2ii
	gen variance=1	
	 
	// Send coefficients to GAUSS
	outsheet * using model_coeffs.asc, replace nonames

	// 2) GAUSS BIT
	shell tgauss -b BSim_Maker_Model.e

// 3)         BASELINE DATA 
output_baseline="bootsimGMM_baseline.asc";
output_nofluct="bootsimGMM_nofluct.asc";
output_5years="bootsimGMM_5years.asc";
output_mistake="bootsimGMM_mistake.asc";
producersurplusfile="psGMM.asc";*/

clear
infile plantid market year actiondata statedata mestate demand comp1 markettype using bootsimGMM_baseline.asc

processcounteranalyze
counteranalyze

tempname bb

matrix `bb'=bm,bm2,flcounty,slcounty,fy,bp
matrix list `bb'

ereturn post `bb'
ereturn local cmd="bootstrap"

end


boot_data

set seed 12345
bootstrap _b, reps(100) saving(boot_data_1, every(1) replace): boot_data

sim_pmu_model
set seed 12345
bootstrap _b, reps(100) saving(boot_pmu_1, every(1) replace): sim_pmu_model

*****************************************************************************************
// MODEL PART
******************************************************************************************

sim_model


// Hack to Pull numbers
global bootpull=1

// Get all bootstrap files
clear
use df_model_2
append using df_model_3
append using df_model_4
append using df_model_5
append using df_model_6
append using df_model_7
append using df_model_8

save boot_df, replace

set seed 12345
bootstrap _b, reps(50) saving(boot_model_1, every(1) replace): sim_model

disp("That's all")







