
/* 
Allan Collard-Wexler
November 11 2009
First Stage of Model

*/

clear
set more off
set mem 500m
set matsize 10000
local x=182
local groupvar="newaverage"
// Load Estout
quietly do "/rdcprojects/ny1/ny00707/programs/estout/estout.ado"
// Load Sutex
quietly do "/rdcprojects/ny1/ny00707/programs/sutex/sutex.ado"

// Load Data
cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/CONCRETE/structure/"
use demand10meanbins`x', replace
sort thedemand `groupvar'
save temp, replace

use exportfile`x'
des
sort thedemand `groupvar'
merge m:1 thedemand `groupvar' using temp
tab _merge

//
//drop if countyindex>30
//

cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/ECMA_RR_ROUND2/"


replace competition=0 if competition==.
gen firstcomp=(competition>=1)
label var firstcomp "First Competitor"
gen secondcomp=(competition>=2)
label var secondcomp "Second Competitor"
gen thirdcomp=(competition>=3)
label var thirdcomp "Third Competitor"
gen logcomp=log(competition+1)
replace logcomp=0 if competition<4
label var logcomp "Log Competitors above 4"
gen lcomp=log(competition+1)
label var lcomp "Log Competitors"

gen lcountyempconstruction=log(countyempcons)
label var lcountyempconstruction "Log County Construction Employment"


replace action=0 if action==.
gen small=action==1
gen medium=action==2
gen large=action==3
gen active=(action>0)


/******************************************************************************************/

/* A Program to Export Estimates */
cap program drop export_coeffs
program export_coeffs
args filenameexport thematrix
matrix exportermatrix=`thematrix'
svmat exportermatrix
outfile exportermatrix* using `filenameexport' in 1, replace
drop exportermatrix*
end


/******************************************************************************************/

/* A Program to Export Data for GAUSS */
cap program drop export_data
program export_data
args filenameexport theg ifcondition

// Some locals
local maxcompetitor=9
local demandstates=10
local maxgroups=4


// Main Data
preserve
keep if `ifcondition'
cap drop thedemand
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
gen thedemand=demandbins

drop if firmstate==.
drop countyindex year firm
drop if thedemand==.
drop if action==.
forval i=1/`maxcompetitor' {
	drop if compstate`i'for==.
}
outfile action compstate* firmstate thedemand `theg' using `filenameexport'_main.fmt, replace
count
matrix exportermatrix=r(N)
svmat exportermatrix
outfile exportermatrix* using `filenameexport'_obs in 1, replace
drop exportermatrix*
restore

// Demand Transition Process
preserve
keep if `ifcondition'
cap drop thedemand

bysort countyindex year: gen first=(_n==1)
keep if first==1
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
// Generate Next Period's Demand
sort countyindex year
tsset countyindex year
gen Fdemand=F.demandbins
gen thedemand=demandbins

// Make Demand Transition Process *
keep countyindex year thedemand Fdemand `theg'
keep Fdemand thedemand `theg'
drop if Fdemand==.
drop if thedemand==.
forval i=1/`demandstates' {
	gen F`i'=(Fdemand==(`i'-1))
}

drop Fdemand

collapse (mean) F*, by (thedemand `theg')  fast
sort `theg' thedemand

drop thedemand `theg'
outfile F* using `filenameexport'_demand.fmt, replace
restore

// Mean of Demand Bins
preserve
keep if `ifcondition'
bysort countyindex year: gen first=(_n==1)
keep if first==1
cap drop thedemand
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
// Export mean of bins in terms of countyempconstruction
collapse (mean) countyempconstruction, by(demandbins `theg')
sort `theg' demandbins 
drop if demandbins==.
outfile demandbins countyempconstruction using `filenameexport'_demandmean.fmt, replace
restore 
end

/******************************************************************************************/


// Generate Means
bysort countyindex year: gen plants=sum(active)
by countyindex year: gen last=(_n==_N)
by countyindex year: gen nplants=plants if last==1
drop plants
bysort countyindex: egen total_plants_pre84=mean(nplants) if year<1984
bysort countyindex: egen total_plants=mean(nplants)
gen pre1983meanplants=round(total_plants_pre84) if year<1984
by countyindex: replace pre1983meanplants=pre1983meanplants[_n-1] if pre1983meanplants==. 
tab pre1983
gen meanplants=round(total_plants)
tab meanplants

gen excluded_mean_plants=.
forval x=1976/1999 {
	cap drop newplants
	gen newplants=nplants if year~=`x' // Plants with Current Year Excluded
	by countyindex: egen meanplants`x'=mean(nplants)  // Mean of Plants
	replace excluded_mean_plants=meanplants`x' if year==`x'
	drop meanplants`x'
}
// Coarse it up
cap drop fexcluded_mean_plants
rename excluded_mean_plants fexcluded_mean_plants
gen excluded_mean_plants=round(fexcluded_mean_plants)
replace excluded_mean_plants=4 if fexcluded_mean_plants>4

gen lagplants=.
forval x=1976/1999 {
	cap drop newplants
	gen newplants=nplants if year<`x' // Plants before Current Year Excluded
	by countyindex: egen meanplants`x'=mean(nplants)  // Mean of Plants
	replace lagplants=meanplants`x' if year==`x'
	drop meanplants`x'
}

// Coarse it up
cap drop flagplants
rename lagplants flagplants
gen lagplants=round(flagplants)
replace lagplants=4 if lagplants>4
replace lagplants=1 if lagplants<1

local spec1="lcountyempconstruction i.firmstate firstcomp secondcomp thirdcomp logcomp"
local spec2="lcountyempconstruction i.firmstate lcomp"
/*-----------------------------------------------------------------------------*/
// Stating the Problem: Binary Logit, Conditional (Market Effect Logit)

logit active `spec1', cluster(countyindex)
estimates store logit1

replace newaverage=4 if newaverage>4
logit active `spec1' i.newaverage, cluster(countyindex)
estimates store logit2

logit active `spec1' i.lagplants, cluster(countyindex)
estimates store logit3

replace pre1983meanplants=4 if pre1983meanplants>4
replace pre1983meanplants=1 if pre1983meanplants<1

logit active `spec1' i.pre1983 if year>1983, cluster(countyindex)
estimates store logit4

// 4 groups of demand levels
by countyindex:egen meandemand=mean(countyempcons)
egen meandemandcat=cut(meandemand), group(4)
tabstat countyempcons, by(meandemandcat) stat(N mean)

logit active `spec1' i.meandemandcat, cluster(countyindex)
estimates store logit5

logit active `spec2', cluster(countyindex)
estimates store logit11

clogit active `spec1', group(countyindex)
estimates store clogit1

estimates table logit1 logit11 logit2 logit3 logit4 logit5 clogit1,se  stats(N N_clust ll chi2)
cap erase logit_fixed_effects.tex
estout logit1 logit2 logit3 logit4  logit5 clogit1 using logit_fixed_effects.tex, style(tex) legend  label stats(N N_clust ll chi2,  fmt(%9.0g %9.2f %9.2f) labels(Observations Markets Log-Likelihood $chi^2$)) cells(b(star fmt(3)) se(par fmt(3))) varlabels(_cons Constant)

// Disclosure Analysis here
cap log close

save temp10, replace

drop if countyempconstruction==. 
log using disclose_logit.txt, text replace
tab active firmstate
tab active firstcomp
tab active secondcomp
tab active thirdcomp
tab active logcomp
tab active meandemandcat
tab active pre1983 if year>1983
tab active lag
disp "Now for the multinomial Choice Problem"

tab action firmstate
tab action firstcomp
tab action secondcomp
tab action thirdcomp
tab action logcomp
tab action meandemandcat
tab action pre1983 if year>1983
tab action lag
log close


/*-----------------------------------------------------------------------------*/
// Model A: 63-67 Mean Plants

mlogit action `spec1', cluster(countyindex)
estimates store modelZ 
export_coeffs modelZbeta e(b)

replace meanplants=4 if meanplants>4
mlogit action `spec1' i.meanplants, cluster(countyindex)
estimates store modelA
export_coeffs modelAbeta e(b)
export_data modelA meanplants action~=.

sureg  (small `spec1') (medium  `spec1') (large  `spec1')
estimates store surA

/*-----------------------------------------------------------------------------*/
// Model B: 76-83 Mean Plants
replace pre1983=4 if pre1983>4
replace pre1983=1 if pre1983==0
mlogit action `spec1' i.pre1983meanplants if year>1983, cluster(countyindex)
estimates store modelB
export_coeffs modelBbeta e(b)
export_data modelB pre1983meanplants year>1983

sureg  (small `spec1' i.pre1983) (medium  `spec1' i.pre1983) (large  `spec1' i.pre1983)
estimates store surB

/*-----------------------------------------------------------------------------*/
// Model C: Log Competition Model
mlogit action `spec2', cluster(countyindex)
estimates store modelC
export_coeffs modelCbeta e(b)
export_data modelC meanplants action~=.

sureg  (small `spec2') (medium  `spec2') (large  `spec2')
estimates store surC

/*-----------------------------------------------------------------------------*/
// Model D: Take out number of plants this year
mlogit action `spec1' i.lag, cluster(countyindex)
estimates store modelD 
export_coeffs modelDbeta e(b)
export_data modelD meanplants action~=.

sureg  (small `spec1' i.lag) (medium  `spec1' i.lag) (large  `spec1' i.lag)
estimates store surD

/*-----------------------------------------------------------------------------*/
/* Put it in a Table*/
estimates table modelA modelB modelC modelD,se  stats(N N_clust ll chi2)

cap erase logit_first_stage.tex
estout modelA modelB modelC modelD using logit_first_stage.tex, style(tex) legend  label stats(N N_clust chi2 ll,  fmt(%9.0g %9.0g %9.2f %9.1f) labels(Observations Markets $\chi^2$ Log-Likelihood))   cells(b(star fmt(3)) se(par fmt(3))) varlabels(_cons \_cons)

estimates table surA surB surC surD,se  stats(N R2)
cap erase sur_first_stage.tex
estout surA surB surC surD using sur_first_stage.tex, style(tex) legend  label stats(N r2,  fmt(%9.0g %9.2f) labels(Observations $R^2$))   cells(b(star fmt(3)) se(par fmt(3))) varlabels(_cons \_cons)



/*-----------------------------------------------------------------------------*/








