/* 
Allan Collard-Wexler
November 11 2009
First Stage of Model

*/

clear
set more off
set mem 2g
set matsize 10000
local x=400
local maxfirms=10
local groupvar="newaverage"
// Load Estout
quietly do "/rdcprojects/ny1/ny00707/programs/estout/estout.ado"
// Load Sutex
quietly do "/rdcprojects/ny1/ny00707/programs/sutex/sutex.ado"


// A Program to Export Estimates 
cap program drop export_coeffs
program export_coeffs
args filenameexport thematrix
matrix exportermatrix=`thematrix'
svmat exportermatrix
outfile exportermatrix* using `filenameexport' in 1, replace
drop exportermatrix*
end


// Load Data
use demand10meanbins400, replace
sort thedemand `groupvar'
save temp, replace

use exportfile`maxfirms'
des
sort thedemand `groupvar'
merge m:1 thedemand `groupvar' using temp
tab _merge

cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/ECMA_4/"


replace competition=0 if competition==.
gen firstcomp=(competition>=1)
label var firstcomp "First Competitor"
gen secondcomp=(competition>=2)
label var secondcomp "Second Competitor"
gen thirdcomp=(competition>=3)
label var thirdcomp "Third Competitor"
gen logcomp=log(competition+1)
replace logcomp=0 if competition<4
label var logcomp "Log Competitors above 4"
gen lcomp=log(competition+1)
label var lcomp "Log Competitors"

gen lcountyempconstruction=log(countyempcons)
label var lcountyempconstruction "Log County Construction Employment"


replace action=0 if action==.
gen small=action==1
gen medium=action==2
gen large=action==3
gen active=(action>0)


******************************************************************************************


//******************************************************************************************

// Some locals
local maxcompetitor=9
local demandstates=10
local maxgroups=4
local theg="newaverage"


// Main Data
preserve
cap drop thedemand
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
gen thedemand=demandbins

drop if firmstate==.
drop countyindex year firm
drop if thedemand==.
drop if action==.
forval i=1/`maxcompetitor' {
	drop if compstate`i'for==.
}

save main_data, replace

outfile action compstate* firmstate thedemand `theg' using D_main.fmt, replace

count
matrix exportermatrix=r(N)
svmat exportermatrix
outfile exportermatrix using bootD_obs in 1, replace
drop exportermatrix*
restore

// Demand Transition Process
preserve
cap drop thedemand

bysort countyindex year: gen first=(_n==1)
keep if first==1
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
// Generate Next Period's Demand
sort countyindex year
tsset countyindex year
gen Fdemand=F.demandbins
gen thedemand=demandbins

// Make Demand Transition Process *
keep countyindex year thedemand Fdemand `theg'
drop if Fdemand==.
drop if thedemand==.
forval i=1/`demandstates' {
	gen F`i'=(Fdemand==(`i'-1))
}

drop Fdemand

save bootdemand_transition, replace
collapse (mean) F*, by (thedemand `theg')  fast
sort `theg' thedemand

drop thedemand `theg'

outfile F* using D_demand.fmt, replace
restore

// Mean of Demand Bins
preserve
bysort countyindex year: gen first=(_n==1)
keep if first==1
cap drop thedemand
// Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `theg'==`groupid', group(`demandstates')
	replace demandbins=tempbins if demandbins==.
}
// Export mean of bins in terms of countyempconstruction

save bootdemand_mean, replace
collapse (mean) countyempconstruction, by(demandbins `theg')
sort `theg' demandbins 
drop if demandbins==.
outfile demandbins countyempconstruction using D_demandmean.fmt, replace
restore 

******************************************************************************************


// Generate Means
bysort countyindex year: gen plants=sum(active)
by countyindex year: gen last=(_n==_N)
by countyindex year: gen nplants=plants if last==1
drop plants
bysort countyindex: egen total_plants_pre84=mean(nplants) if year<1984
bysort countyindex: egen total_plants=mean(nplants)
gen pre1983meanplants=round(total_plants_pre84) if year<1984
by countyindex: replace pre1983meanplants=pre1983meanplants[_n-1] if pre1983meanplants==. 
tab pre1983
gen meanplants=round(total_plants)
tab meanplants

gen excluded_mean_plants=.
forval x=1976/1999 {
	cap drop newplants
	gen newplants=nplants if year~=`x' // Plants with Current Year Excluded
	by countyindex: egen meanplants`x'=mean(nplants)  // Mean of Plants
	replace excluded_mean_plants=meanplants`x' if year==`x'
	drop meanplants`x'
}
// Coarse it up
cap drop fexcluded_mean_plants
rename excluded_mean_plants fexcluded_mean_plants
gen excluded_mean_plants=round(fexcluded_mean_plants)
replace excluded_mean_plants=4 if fexcluded_mean_plants>4

gen lagplants=.
forval x=1976/1999 {
	cap drop newplants
	gen newplants=nplants if year<`x' // Plants before Current Year Excluded
	by countyindex: egen meanplants`x'=mean(nplants)  // Mean of Plants
	replace lagplants=meanplants`x' if year==`x'
	drop meanplants`x'
}
// Coarse it up
cap drop flagplants
rename lagplants flagplants
gen lagplants=round(flagplants)
replace lagplants=4 if lagplants>4
replace lagplants=1 if lagplants<1

local spec1="lcountyempconstruction i.firmstate firstcomp secondcomp thirdcomp logcomp"

save first_stage_4_bootdata, replace

mlogit action `spec1', vsquish noemptycells
mlogit action `spec1' i.newaverage, vsquish noemptycells


// Make Initial States too








