/* 
Allan Collard-Wexler
November 11 2009
First Stage of Model


Modified Groups using fixed effect logit

*/

clear
set more off
set mem 2g
set matsize 10000


local x=400
local groupvar="newaverage"
// Load Estout
quietly do "/rdcprojects/ny1/ny00707/programs/estout/estout.ado"
// Load Sutex
quietly do "/rdcprojects/ny1/ny00707/programs/sutex/sutex.ado"


// A Program to Export Estimates 
cap program drop export_coeffs
program export_coeffs
args filenameexport thematrix
matrix exportermatrix=`thematrix'
svmat exportermatrix
outfile exportermatrix* using `filenameexport' in 1, replace
drop exportermatrix*
end

// Some locals
local maxcompetitor=9
local demandstates=10
local maxgroups=4
local theg="newaverage"

/*

// MAIN BOOTSTRAP LOOP
//cap program drop boot_df_model
//program boot_df_model, eclass
	use first_stage_4_bootdata, clear
	drop if thedemand==.
//	bsample , cluster(countyindex)
	//keep in 1/10000
	// Mlogit
	local spec1="lcountyempconstruction i.firmstate firstcomp secondcomp thirdcomp logcomp"
	mlogit action `spec1' i.newaverage, vsquish noemptycells
	estimates store modelD 
	export_coeffs modelDbeta e(b)
	// Export Data
	outfile action compstate* firmstate thedemand newaverage using bootD_main.fmt, replace
	count
	export_coeffs obs2.fmt r(N)
	// Demand 
	use bootdemand_transition, clear
	//bsample, cluster(countyindex)
	collapse (mean) F*, by (thedemand `theg')  fast
	sort `theg' thedemand
	outfile F* using bootD_demand.fmt, replace
	// Mean of Demand Bins
	use bootdemand_mean, clear
	//bsample, cluster(countyindex)
	collapse (mean) countyempconstruction, by(demandbins newaverage)
	sort newaverage demandbins 
	drop if demandbins==.
	outfile demandbins countyempconstruction using bootD_demandmean.fmt, replace
	
	// GAUSS BIT
	shell tgauss -b Enxit4DFS_Boot.e

	clear
	infile action_data predicted_action statedata mestate demands comps markettype using "CCP_check.raw",clear
	
	gen competition=comps
	gen firstcomp=(competition>=1)
	label var firstcomp "First Competitor"
	gen secondcomp=(competition>=2)
	label var secondcomp "Second Competitor"
	gen thirdcomp=(competition>=3)
	label var thirdcomp "Third Competitor"
	gen logcomp=log(competition+1)
	replace logcomp=0 if competition<4
	label var logcomp "Log Competitors above 4"
	gen lcomp=log(competition+1)
	label var lcomp "Log Competitors"
	
	mlogit action_data demands i.mestate firstcomp-logcomp i.markettype
	estimates store datamlogit
	mlogit predicted_action demands i.mestate firstcomp-logcomp i.markettype
	estimates store ccpmlogit
		
	estimates table datamlogit ccpmlogit

	clear
	// Estimate Model 
	infile action state competitors mestate demands comp_action markettype fixed_cost1 fixed_cost2 fixed_cost3 demand1 demand2 demand3 firstcomp1 logcomp1 firstcomp2 logcomp2  firstcomp3  logcomp3 trans_0_to_1 trans_0_to_2 trans_0_to_3 trans_1_to_2 trans_1_to_3 trans_12_2 trans_12_3 trans_13_2 trans_13_3 trans_2_to_1 trans_2_to_3 trans_23_to_1 trans_23_to_3 trans_3_to_1 trans_3_to_2 epsilons using  "GMAFSs.raw", clear
	save GMAFS, replace
	sum
*/
	use GMAFS, clear
	gen marketfixedcost_2=(fixed_cost1+fixed_cost2+fixed_cost3)*(markettype==1)
	gen marketfixedcost_3=(fixed_cost1+fixed_cost2+fixed_cost3)*(markettype==2)	
	gen marketfixedcost_4=(fixed_cost1+fixed_cost2+fixed_cost3)*(markettype==3)
	
	local reglist="fixed_cost1 fixed_cost2 fixed_cost3 demand1 demand2 demand3 firstcomp1 firstcomp2 firstcomp3 logcomp1 logcomp2 logcomp3 trans_0_to_1 trans_0_to_2 trans_0_to_3 trans_1_to_2 trans_1_to_3 trans_12_2 trans_12_3 trans_13_2 trans_13_3 trans_2_to_1" 
	
	foreach x of local reglist {
		replace `x'=0 if comp_action==0
	}	
	replace trans_2_to_3=0 if comp_action==0
	replace trans_23_to_1=0 if comp_action==0
	replace trans_3_to_1=0 if comp_action==0
	replace trans_3_to_2=0 if comp_action==0


	// Mlogit Part
	gen choice=(action==comp_action)
	
	gen id=ceil(_n/4)

	duplicates drop comp_action id, force
	
	cap gen id=ceil(_n/4)

	set seed 1234
	//gen u=runiform()
	//bysort id: egen newu=mean(u)
	//drop if newu>0.2

	

	constraint 1 epsilons=1 

	gen exit=1 if action==0 & mestate>0
	replace exit=0 if action~=0 & mestate>0
	probit exit i.mestate competitors demands i.markettype if comp_action==0
	
	mlogit action i.mestate demands competitors i.markettype if comp_action==0

	asclogit choice fixed_cost1-epsilons, case(id) alternative(comp_action) noconst constraint(1) iterate(50) from(XX, copy)
	matrix betanofixed=e(b)

	svmat betanofixed, names(beta)
	outfile beta* using thetafsml.asc in 1, replace	
	drop beta*


	tempname bb
	
	asclogit choice fixed_cost1-epsilons marketfixedcost*, case(id) alternative(comp_action) noconst constraint(1)  iterate(50) from(XX, copy)
	matrix betafixed=e(b)

	svmat betafixed, names(beta)
	outfile beta* using thetafsmlfixed.asc in 1, replace	
	drop beta*
	

mata: thetaml=st_matrix("betanofixed")
mata: thetamlfixed=st_matrix("betafixed")
	// II Part 
	

// Indirect Inference Section
gen size1=(mestate==1) | (mestate==2) | (mestate==3)
gen size2=(mestate==4) | (mestate==5)
gen size3=(mestate==6)

cap gen firstcomp=(competitors>0)
cap gen morecomp=log(competitors+1)*(competitors>1)

// MATA ATTEMPT
local iiregressorsm="size1 size2 size3 demands firstcomp morecomp markettype2 markettype3 markettype4"

cap gen markettype2=markettype==1
cap gen markettype3=markettype==2
cap gen markettype4=markettype==3

cap gen choice1=action==1
cap gen choice2=action==2
cap gen choice3=action==3

reg choice1 `iiregressorsm' if comp_action==0
matrix beta1=e(b)
matrix cov1=e(V)
reg choice2  `iiregressorsm' if comp_action==0
matrix beta2=e(b)
matrix cov2=e(V)
reg choice3  `iiregressorsm' if comp_action==0
matrix beta3=e(b)
matrix cov3=e(V)
cap gen const=1

sureg (choice1 `iiregressorsm') (choice2 `iiregressorsm') (choice3 `iiregressorsm')
matrix surcov=e(V)


// Load Data
preserve
keep if comp_action==1
mata: X1=st_data(.,("fixed_cost1-epsilons"))
mata: X1M=st_data(.,("fixed_cost1-epsilons marketfixedcost_2 marketfixedcost_3 marketfixedcost_4"))
restore

preserve
keep if comp_action==2
mata: X2=st_data(.,("fixed_cost1-epsilons"))
mata: X2M=st_data(.,("fixed_cost1-epsilons marketfixedcost_2 marketfixedcost_3 marketfixedcost_4"))
restore

preserve
keep if comp_action==3
mata: X3=st_data(.,("fixed_cost1-epsilons"))
mata: X3M=st_data(.,("fixed_cost1-epsilons marketfixedcost_2 marketfixedcost_3 marketfixedcost_4"))
restore

preserve
keep if comp_action==0
mata: Z=st_data(.,("size1 size2 size3 demands firstcomp morecomp markettype2 markettype3 markettype4 const"))
restore

mata: Z=Z[1..rows(X1),.]
mata: invZZ=invsym(cross(Z,Z))
// 1st Stage Regression
mata: betatrue1=st_matrix("beta1")
mata: cov1=st_matrix("cov1")
mata: betatrue2=st_matrix("beta2")
mata: cov2=st_matrix("cov2")
mata: betatrue3=st_matrix("beta3")
mata: cov3=st_matrix("cov3")
mata: ZW=J(rows(cov1),cols(cov1),0)
mata: W=(invsym(cov1),ZW,ZW)\(ZW,invsym(cov2),ZW)\(ZW,ZW,invsym(cov3))
mata: surcov=st_matrix("surcov")
mata: W2=invsym(surcov)
mata: truebeta=betatrue1,betatrue2,betatrue3

// Criterion
mata:
	void GMMACFCRIT4(todo,thetaguess, truebeta, X1,X2,X3,Z,invZZ,W,Q,  g, H)
        {
	theta=(thetaguess'\1)
	V0=J(rows(X1),1,1)
	V1=exp(X1*theta)
	V2=exp(X2*theta)
	V3=exp(X3*theta)
	Vsum=V0+V1+V2+V3	

	phi0=V0:/Vsum
	phi1=V1:/Vsum
	phi2=V2:/Vsum
	phi3=V3:/Vsum
		
	beta1=invZZ*quadcross(Z,phi1)
	beta2=invZZ*quadcross(Z,phi2)
	beta3=invZZ*quadcross(Z,phi3)
	
	bigbeta=beta1\beta2\beta3
	xi=truebeta'-bigbeta
	Q=-xi'*W*xi
	}
end

mata: thetaguess=XX

	// Junk to Initialize Nelder-Mead Maximizer
mata: S = optimize_init()
mata: optimize_init_evaluator(S, &GMMACFCRIT4())

	// initial values
mata: optimize_init_params(S, thetaguess)
mata: optimize_init_tracelevel(S,"none")
mata: optimize_init_evaluatortype(S, "d0")
mata: optimize_init_technique(S, "nm") 
mata: optimize_init_conv_maxiter(S, 10000) 
//mata: optimize_init_technique(S, "bfgs") 
//mata: optimize_init_conv_maxiter(S, 100) 
mata: optimize_init_nmsimplexdeltas(S, 1) 
mata: optimize_init_argument(S, 1, truebeta)
mata: optimize_init_argument(S, 2, X1)
mata: optimize_init_argument(S, 3, X2)
mata: optimize_init_argument(S, 4, X3)
mata: optimize_init_argument(S, 5, Z)
mata: optimize_init_argument(S, 6, invZZ)
mata: optimize_init_argument(S, 7, W)


mata: pamoeba=thetaguess

forval i=1/20{
mata: optimize_init_params(S, pamoeba)
mata: pamoeba=optimize(S)
mata: optimize_result_value(S)
mata: optimize_result_value0(S)
mata: pamoeba

mata: st_matrix("beta",pamoeba)
svmat beta, names(theta)
outfile theta* using thetafs1.asc in 1, replace	
drop theta*
}

mata: optimize_init_argument(S, 7, W2)
mata: pamoeba=thetaguess
mata: optimize_init_params(S, thetaguess)


forval i=1/20{
mata: pamoeba=optimize(S)
mata: optimize_result_value(S)
mata: optimize_result_value0(S)
mata: pamoeba

mata: st_matrix("beta",pamoeba)
svmat beta, names(theta)
outfile theta* using thetafs2.asc in 1, replace	
drop theta*

mata: optimize_init_params(S, pamoeba)
}


mata: pamoeba=thetaml[1..27]
mata: optimize_init_argument(S, 7, W)
mata: optimize_init_params(S, thetaml[1..27])

forval i=1/20{
mata: pamoeba=optimize(S)
mata: optimize_result_value(S)
mata: optimize_result_value0(S)
mata: pamoeba


mata: st_matrix("beta",pamoeba)
svmat beta, names(theta)
outfile theta* using thetafs1mlstart.asc in 1, replace	
drop theta*

mata: optimize_init_params(S, pamoeba)
}



mata: thetaguess2=XX

mata: pamoeba=thetaguess2

mata: optimize_init_params(S, thetaguess2)
forval i=1/20{
mata: pamoeba=optimize(S)
mata: optimize_result_value(S)
mata: optimize_result_value0(S)
mata: pamoeba


mata: st_matrix("beta",pamoeba)
svmat beta, names(theta)
outfile theta* using thetafs3.asc in 1, replace	
drop theta*

mata: optimize_init_params(S, pamoeba)
}

disp("That's all")









