/*------------------------------------------------------------------------------------------------------------
ALLAN COLLARD-WEXLER

December 3 2005
 
 Make Data for Entry Exit model with Different Demand Transition Probabilities for each market.
------------------------------------------------------------------------------------------------------------
*/
set more off
cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/CONCRETE/"
clear
local maxfirms=10
local demandstates=10
local maxdemand=exp(12)
local maxgroups=4
local groupvar="newaverage"
local maxnoentry=10
local markettype="newaverage";
local x=400
set mem 500m
use lcd5c
drop countyindex
egen countyindex=group(state county)

cd "/rdcprojects/ny1/ny00707/transfer_proj422/ch00422/ECMA_4"
bysort county state year:egen maxdemand=max(w20Mempconstruction)
bysort county state: egen marketyear=sum((year)~=.)
tab marketyear
drop if (marketyear<20)|(marketyear>24)
drop if maxdemand>`maxdemand'

drop if (maxplants>`maxfirms')&(maxplants~=.)
drop if maxplant==.
drop if year==1999
gen dcountypayconstruction=countypayconstruction/cpi

* Generate Groups

replace newaverageplants=4 if (newaverageplants==5 | newaverageplants == 6)


drop if (newaverageplants==0 | newaverageplants>4)

tab newaverage 


* Make Gride of Demand Variables
gen demandbins=.
forval groupid=1/`maxgroups' {
	capture drop tempbins
	egen tempbins=cut(countyempconstruction) if `groupvar'==`groupid', group(`demandstates') 
	replace demandbins=tempbins if demandbins==.
}



* Generate Next Period's Demand
sort countyindex year
tsset countyindex year
gen Fdemand=F.demandbins

preserve

* Some summary statistics
tab countynplants
sum jmbirth*
sum jmdeath*
gen isnoentry=0

format plantindex* %15.0f

********************************************************************************************************
/* MODEL OF FIRM SIZE*/
forval i=1/`maxfirms' {
	/*gen action`i'=((plantindex`i'~=.)&(jmdeath`i'~=1)&(jmdeath`i'~=.))+((Femp`i'>15)&(Femp`i'~=.))
	gen firmstate`i'=((plantindex`i'~=.)&(jmbirth`i'~=1)&(jmbirth`i'~=.))+((emp`i'>15)&(emp`i'~=.))*/
	
	/*gen action`i'=((plantindex`i'~=.)&(jmdeath`i'~=1)&(jmdeath`i'~=.))+((Femp`i'>7)&(Femp`i'~=.))+((Femp`i'>16)&(Femp`i'~=.))
	gen firmstate`i'=((plantindex`i'~=.)&(jmbirth`i'~=1)&(jmbirth`i'~=.))+((emp`i'>7)&(emp`i'~=.))+((emp`i'>16)&(emp`i'~=.))*/
	
	gen action`i'=((plantindex`i'~=.)&(jmdeath`i'~=1)&(jmdeath`i'~=.))+((Femp`i'>7)&(Femp`i'~=.))+((Femp`i'>16)&(Femp`i'~=.))
	gen firmstate`i'=((plantindex`i'~=.)&(jmbirth`i'~=1)&(jmbirth`i'~=.))+((emp`i'>7)&(emp`i'~=.))+((emp`i'>16)&(emp`i'~=.))
	
	// I'm changing this line since firms that exit seem to end up with observations even if they are exiting. (difference between boot 4 and boot 3)
	replace firmstate`i'=0 if emp`i'==. 

	gen hpstate`i'=((plantindex`i'~=.)&(jmbirth`i'~=1)&(jmbirth`i'~=.))+((HPemp`i'>7)&(HPemp`i'~=.))+((HPemp`i'>16)&(HPemp`i'~=.))
	
	gen newstate=firmstate`i'
	replace firmstate`i'=0
	replace firmstate`i'=6 if (newstate==3)
	
	replace firmstate`i'=4 if (newstate==2)
	replace firmstate`i'=5 if (newstate==2) & (hpstate`i'==3)
	
	replace firmstate`i'=1 if (newstate==1) 
	replace firmstate`i'=2 if (newstate==1) & (hpstate`i'==2)
	replace firmstate`i'=3 if (newstate==1) & (hpstate`i'==3)
	
		
	replace action`i'=. if firmstate`i'~=0 & jmdeath`i'==.
	replace firmstate`i'=. if firmstate`i'~=0 & jmbirth`i'==.
	gen thedemand`i'=demandbins
	cap drop newstate
	
}


/* MODEL OF OUT INACTIVE ACTIVE

forval i=1/`maxfirms' {
	gen action`i'=((plantindex`i'~=.)&(jmdeath`i'~=1)&(jmdeath`i'~=.))+((Femp`i'>0)&(Femp`i'~=.))
	gen firmstate`i'=((plantindex`i'~=.)&(jmbirth`i'~=1)&(jmbirth`i'~=.))+((emp`i'>0)&(emp`i'~=.))
	replace action`i'=. if firmstate`i'~=0 & jmdeath`i'==.
	replace firmstate`i'=. if firmstate`i'~=0 & jmbirth`i'==.
	gen thedemand`i'=demandbins
}
*/

tab action1 firmstate1 if demandbins~=.

forval i=1/`maxfirms' {
	local thecomp=0
	forval j=1/`maxfirms' {
		* Need to skip over own firm
		local thecomp=`thecomp'+(`j'~=`i')
		if (`j'~=`i') {
		gen compstate`thecomp'for`i'=firmstate`j'
		}
		}
	}



local compstatelist=""
local maxcompetitor=`maxfirms'-1
forval i=1/`maxcompetitor' {
	local compstatelist="`compstatelist' compstate`i'for"
}

// Check the actions and stuff.
list action* firmstate* plantindex*  emp* year if countyindex==20



* Reshape Stuff
keep action* firmstate* compstate* thedemand* `markettype' countyindex year 
reshape long action firmstate `compstatelist' thedemand , i(countyindex year) j(firm)
gen birth=(action==1)&(firmstate==0)
gen death=(action==0)&(firmstate==1)



forval i=1/`maxcompetitor' {
	gen big`i'=(compstate`i'==2)
	gen small`i'=(compstate`i'==1)
	gen competition`i'=(compstate`i'>0)
}


egen competition=rsum(competition*)
egen bigcomp=rsum(big*)
egen smallcomp=rsum(small*)


save exportfile`maxfirms', replace
drop if firmstate==.
drop countyindex year firm
drop if thedemand==.
drop if action==.
forval i=1/`maxcompetitor' {
	drop if compstate`i'for==.
}
outfile action compstate* firmstate thedemand newaverageplants using Mexport`maxfirms'file`x'.fmt, replace

count

******************************************************************************************
restore
rename demandbins thedemand
preserve
* Make Demand Transition Process *
keep countyindex year thedemand Fdemand `groupvar'
keep Fdemand thedemand `groupvar'
drop if Fdemand==.
drop if thedemand==.
forval i=1/`demandstates' {
	gen F`i'=(Fdemand==(`i'-1))
}

drop Fdemand

collapse (mean) F*, by (thedemand `groupvar')  fast
sort `groupvar' thedemand

drop thedemand `groupvar'
save temp, replace
outfile F* using demand`maxfirms'exportfile`x'.fmt, replace
save multidemandexportfile, replace

**********************************************************************************************
* Also export mean of bins in terms of countyempconstruction
restore
collapse (mean) countyempconstruction, by(thedemand `groupvar')
sort `groupvar'  thedemand 
drop if thedemand==.
outfile thedemand countyempconstruction using demand`maxfirms'meanbins`x'.fmt, replace
rename `groupvar' markettype
rename thedemand demand 
sort demand markettype
save demand`maxfirms'meanbins`x', replace
count
