*-------------------------------------------------------------------------
* Allan Collard-Wexler
* August 10, 2004
*
* GENERATE COUNTY LEVEL MARKET DATA SET
*------------------------------------------------------------------------

clear
set mem 800m
cd /rdcprojects/ch00422/CONCRETE
use countydistances
*First we generate the year*county data set
rename state_fips state
rename cnty_fips county
* Here is the important step
cross using year
sort state county year
save countyset3, replace


* First we merge the county level data with the lcd
clear
use lcd2
* Our data file is getting a bit too big so we keep a subset of variables
keep concretesic concreteind cfn lbdnum plantindex ppn year ind tvs te ar state firmid frmnu lfo ph pe plac pw1 pw2 pw3 pw4 tab tae tce td tvmc va sw emp pay flaga mu flagb sic firstyear lastyear empconstruction payconstruction empintensity payintensity  lbdentry age lva lsw ltae productivitycobbdouglas jmbirth jmdeath young small crash d1competition empshare d1empshare vashare producesconcrete2 comp county

* We now need to drop some states which are outside the U.S.
drop if state==66 | state==69 | state==72 | state==78 | state==97 | state==98

sort state county year
merge state county year using countyset3
gen nplants=(plantindex~=.)

tab _merge
quietly destring ncf*, replace

*drop curpc1- pvit3721855
save lcd3, replace



* Next we create market level aggregates

use lcd3, clear

local countyvar "tvs va tae tab te sw empconstruction payconstruction productivity nplants emp pay"
local countyvarsum "tvs va tae tab te sw  nplants emp pay"
local countyvarmedian "empconstruction payconstruction productivity"
drop if year==2000 | year==1973 | year==1974 | year==1975
*Here it is important that we eliminate out of industry variables.
drop if (concretesic<0.5 | concreteind<0.5)

save lcd3, replace

*tempfile temp1 temp2

*First, let's collapse to the county/year level
collapse (sum) `countyvarsum' (median) `countyvarmedian' (median) ncfips*, by(state county year)
gen tfips=state*1000+county
drop if tfips==.
sort tfips year
save temp2, replace
foreach x of local countyvar {
	rename `x' temp`x'
	}
save temp1, replace

* Make
use temp2, clear
gen cfips=state*1000+county
keep cfips year ncfips*
save temp3, replace
*/
local countyvar "tvs va tae tab te sw empconstruction payconstruction productivity nplants emp pay"
local countyvarsum "tvs va tae tab te sw  nplants emp pay"
local countyvarmedian "empconstruction payconstruction productivity"

use temp3, clear
reshape long ncfipsadj,i(cfips year) j(neighbourcode)
keep cfips year ncfipsadj
save temp4, replace
use temp3, clear
reshape long ncfips10m,i(cfips year) j(neighbourcode)
keep cfips year ncfips10m
save temp5, clear
use temp3, clear
reshape long ncfips20m,i(cfips year) j(neighbourcode)
keep cfips year ncfips20m
save temp6, clear



keep cfips year ncfipsadj*
forval i=1/1 {
	rename ncfipsadj`i' tfips
	sort tfips year
	merge tfips year using temp1
	collapse (sum) `countyvarsum' (median) `countyvarmedian' (median) ncfips*, by(state county year)
	}

foreach x of local countyvar {
	gen double adj`x'=0
	gen double w10M`x'=0
	gen double w20M`x'=0
	}
foreach x of local countyvar {
	rename `x' county`x'
	}
rename tfips cfips
save temp2, replace

forval i=1/12 {
	use temp2, clear
	gen tfips=ncfipsadj`i'
	sort tfips year
	merge tfips year using temp1
	display "`i'"
	quietly {
	foreach x of local countyvar {
		replace adj`x'=adj`x'+temp`x' if temp`x'~=.
		*replace adj`x'=temp`x' if adj`x'==.
		}
	tab _merge
	drop if _merge==2
	drop _merge tfips temp*
	save temp2, replace
	}
}
forval i=1/17 {
	use temp2, clear
	gen tfips=ncfips10m`i'
	sort tfips year
	merge tfips year using temp1
	display "`i'"
	quietly {
	foreach x of local countyvar {
		replace w10M`x'=w10M`x'+temp`x' if temp`x'~=.
		*replace w10M`x'=temp`x' if w10M`x'==.
		}
	tab _merge
	drop if _merge==2
	drop _merge tfips temp*
	save temp2, replace
	}
}
forval i=1/24 {
	use temp2, clear
	gen tfips=ncfips20m`i'
	sort tfips year
	merge tfips year using temp1
	display "`i'"
	quietly {
	foreach x of local countyvar {
		replace w20M`x'=w20M`x'+temp`x' if temp`x'~=.
		*replace w20M`x'=temp`x' if w20M`x'==.
		}
	tab _merge
	drop if _merge==2
	drop _merge tfips temp*
	save temp2, replace
	}
}
* Generate number of neighbouring counties
egen neighboursadj=rmiss(ncfipsadj*)
egen neighboursw10M=rmiss(ncfips10m*)
egen neighboursw20M=rmiss(ncfips20m*)
replace neighboursadj=12-neighboursadj
replace neighboursw10M=17-neighboursw10M
replace neighboursw20M=24-neighboursw20M
drop ncfips*
*eliminate AR year aggregates
local yearlist="1976 1978 1979 1980 1981 1983 1984 1985 1986 1988 1989 1991 1993 1994 1995 1996 1998 1999 2000"
local cmvars="tvs va tae sw te productivity"
local rtype="county adj w10M w20M"

quietly {
foreach x of local yearlist {
	foreach y of local cmvars {
		foreach z of local rtype {
			replace `z'`y'=. if year==`x'
			}
	}
}
}
quietly compress
save lcd4, replace
* Here we add County descriptors
use lcd4
sort state county year
save lcd4, replace
use countyset
drop ncf*
sort state county year
save temp1, replace
use lcd4
merge state county year using temp1
drop _merge
quietly compress
save lcd4, replace

