**********************************************************************
* ALLAN COLLARD-WEXLER
* June 26 2005
* Make Prices
* This program generate plant level concrete prices using R/Q 
* according to Syverson 2004 procedure
* 
**********************************************************************

* Generate prices for concrete and pull them into the lcd3 datafile
clear
set mem 600m

use lcd2
* Eliminate Non-Census Years: No Product Data
drop if (mod(year-1967,5)~=0)&(year~=1963)

* Price are generated: Value/Quantity
gen price3273000=pv3273000/pqs3273000 if ar==0

replace price=. if price==0
* In 1982 the units are different
replace price=price/1000 if year==1982


* Drop prices if they are 5 times lower or higher than median price in the year
bysort year: egen medianprice=median(price)
replace price=.  if price>5*medianprice
replace price=.  if price<(1/5)*medianprice


* Drop cold deck impute: price same as the mode
bysort year price: egen numberprice=sum(price~=.)
tab numberprice
bysort year: egen modeprice=mode(price)
replace price=.  if price==modeprice


sum price, detail

* Merge Prices into lcd3
keep plantindex year price numberprice
sort plantindex year
save temp, replace

use lcd3, clear
sort plantindex year
drop _merge
merge plantindex year using temp
drop _merge

* Merge in deflators too
preserve
use yeardata, clear
sort year
save yeardata, replace
restore
sort year
merge year using yeardata
drop _merge

* First lets rescale price so it makes sense
replace price=price*1000
gen lprice=log(price)

* Deflate Price by ready-mix price
gen defprice=(price/ready)*100


*replace competition=0 if competition==.
drop if county==.

* Lets demean the prices by year
egen averageinyear=mean(price), by(year)
gen dprice=price/averageinyear
gen dlprice=log(price)-log(averageinyear)


log using MakePrices, replace

sum price lprice defprice dlprice if competition<10 & numberprice==1

xi:reg price competition i.year if competition<10 & numberprice==1
xi:reg lprice competition i.year if competition<10 & numberprice==1

reg dlprice competition area if competition<10 & numberprice==1

xi: reg price i.competition i.year area   if competition<10 & numberprice==1
xi: reg defprice i.competition area   if competition<10 & numberprice==1
xi: qreg defprice i.competition area  if competition<10 & numberprice==1
xi: qreg price i.competition i.year area  if competition<10 & numberprice==1
log close
log using MakePricesDisclose, replace
gen touse=~(numberprice==1 & competition<10)
cd Disclosure
do disclose
forval i=1/10 {
	replace touse=(numberprice==1 & competition==`i')
	do disclose
}
do disclose
log close





