# Make Estimates and Counterfactuals in 
# Demand Fluctuations in RMC
# Allan Collard-Wexler

#-------------------------------------------------
# A. Extract the Data from the LBD, CMF, ASM Files
#-------------------------------------------------

sas indexmerge.sas
# construction data
extractconstruction.sas
# producers of concrete
extractconcreteproducers.sas

#-------------------------------------------------
# B. Assemble Raw Data files
#-------------------------------------------------


# Bring in the data to STATA
stata-mp -b do importpaneldatafromsas.do
# Put LBD, CMF, ASM together
stata-mp -b do mergelrdb.do
# Sort out if a firm is in ready-mix concrete
stata-mp -b do belongtocrete.do

# Add Contruction data
stata-mp -b do aggregateconstruction2.do

# Merge in Product trailer
stata-mp -b do makeprod.do
stata-mp -b do makematcmf.do

# Make the final dataset: lcd4 (county level aggregates)
stata-mp -b do MakePlantCountyData2.do
stata-mp -b do MakeNewLcd5.do

# Look at Price Data
stata-mp -b do MakePrices.do

#-------------------------------------------------
# C. Estimates of the Model
#-------------------------------------------------

# 1. Make the data for the structural estimates, and first stage estimates
stata-mp -b do MakeEntryExitGauss4MD.do
# Descriptive Regressions
stata-mp -b do First_Stage2.do

# 2. Main Estimates
# First Stage
stata-mp -b do First_Stage5.do

# Compile C files
shell gcc -c -O6 -fPIC pm14l.c;
shell ld -G -o pm14l.so pm14l.o;

# Second Stage.
# Bootstraps (will take about 30 days)
stata-mp -b do First_Stage6_FS_6_boot.do 
# (Calls shell tgauss -b Enxit4DFS_Boot.e in the Stata program).

# 3. Check Prediction
tgauss -b Sim_Maker_Model.e > Sim_Maker_Model.log
# (Calls Stata Code shell stata-se -b do AnalyzeSimData_SimModel.do)

# 4. Make Bootstraps
stata-mp -b do Boot_Sim.do


# 5. Counterfactuals
tgauss -b CF_Maker.e > CF_Maker.log