*-------------------------------------------------------------------------
* Allan Collard-Wexler
* July 27, 2004
*
* RESHAPE MATERIAL TRAILER FOR IMPORT INTO LCD
*-------------------------------------------------------------------------


* This do file reshapes the material trailers to be merged with data on firm in our LCD *(longitudinal concrete data)
* Note that we will use variables corresponding to the NAICS product codes of the most used * products (value weighted of course)

clear
use cmfmatpanelb
*First we add labels to the variables
label variable cp "Cost of Materials and Parts"
label variable ind "Tabulated Industry Code"
label variable m "Material Code Published"
label variable mc "Delivered Cost of Materials"
label variable mcf "Cost of Materials Flag"
label variable mcol "Material Code Collected"
label variable mf "Materials Flag"
label variable mnaics "NAICS Material Code"
label variable mqdc "Quantity Received and Consummed"
label variable mqdcf "Materials Received Flag"
label variable mqpc "Quantity Produced and Consummed"
label variable ppn "Permanent Plant Number"
label variable seqnmats "Materials Consummed Record Sequence Number"
label variable seqnmst "Master Record Sequence Number"
label variable statp "Statistical Period"
label variable tdcp "Total Detailed Cost of Materials"
label variable tvmc "Total Value of Materials Consummed"
label variable year "Survey Year"
label variable cfn "Census File Number"


* First we will convert this data set to single observation style
sort cfn year seqnmats
drop in 37770
*keep in 1/1000

drop seqnmst
quietly reshape wide  ppn-mqpc,i(cfn year) j(seqnmats)
*sum mc1 mc5 mc10 mc15 mc20 mc25
local constantvar "ppn cp tdcp tvmc ind statp"
local nonconstantvar "m mcol mnaics mc mcf mf mqdc mqdcf mqpc"
* Generate new variables with these
local newvar "m mc mcf mf mqdc mqdcf mqpc"
local newvarstring "m mcf mf mqdcf"
local newvarnum "mc mqdc mqpc"


foreach k of local constantvar {
rename `k'1 `k'
forvalues x=2/34 {
	drop `k'`x'
}
}

* Define the set of NAICS product codes we want to treat differently
local naicsmats "3241 9710 1442 9700 9720 1422 2810 2141 1420 1429 9760 3200 3724 3295 1423 2911 3310 9730 3728 2800 2833"

* First we need to make sure the new variables have the same type as the old ones


* We only want 4 digit product codes for materials
forvalues y=1/34 {
	gen shortm`y'=m`y'
	recast str4 shortm`y', force
	label variable m`y' "Material Code Published for material number `y'"
	label variable mc`y' "Delivered Cost of Materials for material number `y'"
	label variable mcf`y' "Cost of Materials Flag for material number `y'"
	label variable mcol`y' "Material Code Collected for material number `y'"
	label variable mf`y' "Materials Flag for material number `y'"
	label variable mnaics`y' "NAICS Material Code for material number `y'"
	label variable mqdc`y' "Quantity Received and Consummed for material number `y'"
	label variable mqdcf`y' "Materials Received Flag for material number `y'"
	label variable mqpc`y' "Quantity Produced and Consummed for material number `y'"
}

quietly {
foreach x of local naicsmats {
	foreach z of local newvarstring {
		gen `z'`x'=`z'1
		replace `z'`x'="."
	}
	foreach z of local newvarnum {
		gen `z'`x'=`z'1
		replace `z'`x'=.
	}
}
foreach y of local naicsmats {
	label variable m`y' "Material Code Published for NAICS `y'"
	label variable mc`y' "Delivered Cost of Materials for NAICS `y'"
	label variable mcf`y' "Cost of Materials Flag for NAICS `y'"
	*label variable mcol`y' "Material Code Collected for NAICS `y'"
	label variable mf`y' "Materials Flag for NAICS `y'"
	*label variable mnaics`y' "NAICS Material Code for NAICS `y'"
	label variable mqdc`y' "Quantity Received and Consummed for NAICS `y'"
	label variable mqdcf`y' "Materials Received Flag for NAICS `y'"
	label variable mqpc`y' "Quantity Produced and Consummed for NAICS `y'"
}
}

quietly {
foreach x of local naicsmats {
forvalues y=1/34 {
	foreach z of local newvarstring {
		replace `z'`x'=`z'`y' if shortm`y'=="`x'"
		*replace `z'`y'="." if shortm`y'=="`x'"
				}
	foreach z of local newvarnum {
		replace `z'`x'=`z'`y' if shortm`y'=="`x'" & `z'`x'==.
		replace `z'`x'=`z'`y'+`z'`x' if shortm`y'=="`x'" & `z'`x'~=.
		*replace `z'`y'=. if shortm`y'=="`x'"
				}

	}
}
}



quietly compress

save newmat, replace
